.modal-small .fa,.waterfall .content .inner-content .svg-container svg .chart .builder .build{cursor:pointer}.waterfall{position:absolute;top:52px;left:20px;bottom:0;right:0;width:auto;overflow-x:auto;overflow-y:hidden}.waterfall .load-indicator{position:fixed;top:52px;left:20px;padding-right:20px;width:100%;height:100%;z-index:900;background-color:#fff;display:table}.waterfall .load-indicator .spinner{display:table-cell;vertical-align:middle;text-align:center}.waterfall .load-indicator .spinner p{font-weight:300;margin-top:10px}.waterfall .header{position:relative;z-index:1;height:100px;line-height:100px;margin-bottom:2px;margin-right:-150px;vertical-align:middle}.waterfall .header .header-content{height:100%;overflow:hidden}.waterfall .header .header-content svg{width:100%;height:100%}.waterfall .header .header-content .axis .domain{fill:none}.waterfall .header .header-content .axis.x .tick a{text-decoration:none}.waterfall .header .header-content .axis.x .tick text{fill:#3498db;font-size:12px}.waterfall .header .header-content .axis.x .tick line{stroke-width:20px}.waterfall .content{position:relative;height:100%}.waterfall .content .inner-content{position:absolute;top:0;bottom:110px;overflow-y:auto;overflow-x:visible;width:100%}.waterfall .content .inner-content .svg-container{position:relative;width:100%;height:16000px}.waterfall .content .inner-content .svg-container svg{width:100%;height:100%}.waterfall .content .inner-content .svg-container svg .chart .builder .build polygon,.waterfall .content .inner-content .svg-container svg .chart .builder .build rect{stroke:#3498db;stroke-width:1px}.waterfall .content .inner-content .svg-container svg .chart .builder .build polygon{fill:#fff}.waterfall .content .inner-content .svg-container svg .chart .builder .build .buildstep text{font-size:12px}.waterfall .content .inner-content .svg-container svg .chart .builder text.id{fill:#3498db;font-size:12px;text-anchor:middle}.waterfall .content .inner-content .svg-container svg .chart .builder circle{stroke:#3498db;stroke-width:1px}.waterfall .content .inner-content .svg-container svg .axis .domain{fill:none}.waterfall .content .inner-content .svg-container svg .axis.y .tick text{fill:#3498db;font-size:10px}.waterfall .content .inner-content .svg-container svg .axis.y .tick line{stroke:#3498db;stroke-width:1px}.waterfall .fill.success{fill:#8D3}.waterfall .fill.warnings{fill:#FA3}.waterfall .fill.failure{fill:#E88}.waterfall .fill.skipped{fill:#ADE}.waterfall .fill.exception{fill:#C6C}.waterfall .fill.cancelled,.waterfall .fill.retry{fill:#ECC}.waterfall .fill.pending{fill:#E7D100}.waterfall .fill.unknown{fill:#EEE}.waterfall .stroke.success{stroke:#8D3}.waterfall .stroke.warnings{stroke:#FA3}.waterfall .stroke.failure{stroke:#E88}.waterfall .stroke.skipped{stroke:#ADE}.waterfall .stroke.exception{stroke:#C6C}.waterfall .stroke.cancelled,.waterfall .stroke.retry{stroke:#ECC}.waterfall .stroke.pending{stroke:#E7D100}.waterfall .stroke.unknown{stroke:#EEE}.svg-tooltip{pointer-events:none}.modal-small .modal-dialog{width:80%}